module.exports.default = [
	function () {
		return {};
	}
];
